@@ -64,6 +64,9 @@
 /* localization headers and defines */
 #include <libintl.h>
 #include <locale.h>
+#ifdef USE_CONIC
+#include <conic/conic.h>
+#endif
 /*******************************************************************************/
 #define _(String) dgettext (GETTEXT_PACKAGE, String)
 #define Max_count_weather_day	10
@@ -256,6 +259,11 @@ typedef struct OMWeatherApplet{
     Station		gps_station;
     gdouble		temporary_station_latitude;
     gdouble		temporary_station_longtitude;
+#endif    
+    gchar               temperature_string[1024];
+    gchar               forecast_string[2048];
+#ifdef USE_CONIC    
+    ConIcConnection 	*connection;
 #endif    
 }OMWeatherApp;
 
