@@ -255,6 +255,56 @@ void station_error_window(void){
 				    _("Wrong station code \nor ZIP code!!!"));
 }
 /*******************************************************************************/
+int calculate_offset_of_day(int count_day){
+
+    long int    diff_time;
+    int		year,
+    		current_month,
+		offset;
+    time_t	current_day,
+		current_time,
+		utc_time,
+		date_time;
+    struct tm	*tm = NULL;
+    double	pre_offset = 0.0F;
+    gchar	date_in_string[255];
+
+/* get current day */  
+    current_time = time(NULL);
+    utc_time = mktime(gmtime(&current_time));
+    diff_time = utc_time - current_time + 60 * 60 * atol(item_value(wcs.day_data[0], "station_time_zone"));
+    current_time += diff_time;
+    current_day = current_time;
+    tm = localtime(&current_day);
+    year = 1900 + tm->tm_year;
+    current_month = tm->tm_mon;
+    tm->tm_sec = 0; tm->tm_min = 0; tm->tm_hour = 0;
+    current_day = mktime(tm);
+
+    memset(date_in_string, 0, sizeof(date_in_string));
+    sprintf(date_in_string, "%s %i 00:00:00",
+	    item_value(wcs.day_data[0], "24h_date"), year);
+
+    strptime(date_in_string, "%b %d %Y %T", tm);
+    /* Check New Year */
+    if((current_month == 11) && (tm->tm_mon == 0)){
+	sprintf(date_in_string, "%s %i 00:00:00",
+		item_value(wcs.day_data[count_day - 1], "24h_date"), year + 1);
+	strptime(date_in_string, "%b %d %Y %T", tm);
+    }
+    date_time = mktime(tm);
+    /* calculate days offset */
+    pre_offset = (double)(abs(current_day - date_time));
+    pre_offset /= 24.0F * 60.0F * 60.0F;
+    offset = (int)( round(pre_offset) );
+
+    if(offset >= Max_count_weather_day || count_day < 0)
+	offset = Max_count_weather_day;
+    
+    return offset;    
+    
+}
+/*******************************************************************************/
 /* Filling data of buttons  */
 void weather_buttons_fill(gboolean check_error){
     int		i,
@@ -262,19 +312,18 @@ void weather_buttons_fill(gboolean check_error){
 		k = 0,
 		offset = 0,
 		count_day,
-		year,
-		current_month = 1;
+		current_month,
+		year;
     gchar	buffer[2048],
 		buffer_icon[2048],
 		date_in_string[255];
-    time_t	current_day,
-		current_time,
-		last_day = 0,
+    time_t	current_time,
+    		current_day,
 		utc_time,
+		last_day = 0,
 		date_time,
 		day_begin_time,
 		night_begin_time;
-    long int    diff_time;
     struct tm	*tm = NULL,
 		tmp_tm;
     gboolean	flag_last_day = FALSE,
@@ -283,7 +332,12 @@ void weather_buttons_fill(gboolean check_error){
     char	font_size;
     gint	icon_size;
     gchar	*tmp_station_name;
-    double	pre_offset = 0.0F;
+    long int    diff_time;
+    const gchar	*wind_units_str[] = {	"m/s",
+					"km/h",
+					"mi/h"
+				    };
+
 #ifndef RELEASE
     time_t	tmp_time;
 
@@ -317,6 +371,8 @@ void weather_buttons_fill(gboolean check_error){
 	    icon_size = TINY_ICON_SIZE;
 	break;        
     }
+    memset(app->temperature_string, 0, sizeof(app->temperature_string));
+    memset(app->forecast_string, 0, sizeof(app->forecast_string));
 /* Init weather buttons */
     count_day = new_parse_weather_com_xml();
 /*    parse_underground_com_data("26666");	* TODO next release, maybe */
@@ -340,26 +396,8 @@ void weather_buttons_fill(gboolean check_error){
     tm->tm_sec = 0; tm->tm_min = 0; tm->tm_hour = 0;
     current_day = mktime(tm);
 
-    memset(date_in_string, 0, sizeof(date_in_string));
-    sprintf(date_in_string, "%s %i 00:00:00",
-	    item_value(wcs.day_data[0], "24h_date"), year);
-
-    strptime(date_in_string, "%b %d %Y %T", tm);
-    /* Check New Year */
-    if((current_month == 11) && (tm->tm_mon == 0)){
-	sprintf(date_in_string, "%s %i 00:00:00",
-		item_value(wcs.day_data[count_day - 1], "24h_date"), year + 1);
-	strptime(date_in_string, "%b %d %Y %T", tm);
-    }
-    date_time = mktime(tm);
-    /* calculate days offset */
-    pre_offset = (double)(abs(current_day - date_time));
-    pre_offset /= 24.0F * 60.0F * 60.0F;
-    offset = (int)( round(pre_offset) );
-
-    if(offset >= Max_count_weather_day || count_day < 0)
-	offset = Max_count_weather_day;
-    /* delete old weather data */
+    offset = calculate_offset_of_day(count_day);
+/* delete old weather data */
     for(i = 0; i < offset; i++)
 	destroy_object(&(wcs.day_data[i]));
     /* move weather data */
@@ -388,9 +426,8 @@ void weather_buttons_fill(gboolean check_error){
 	    }
 	    date_time = mktime(tm);	
 	
-	    if(i == 0 || (app->config->separate && i == 1)){	/* first day */
-		/* repeat the same data in second button for first day if data is config->separate */
-		(app->config->separate && i == 1) ? (j = -1) : (j = 0);
+	    if(i == 0){	/* first day */
+
 		/* prepare temperature for first day */
 		if(!strcmp(item_value(wcs.day_data[i + j], "24h_hi_temperature"), "N/A"))
 		    temp_hi = INT_MAX;
@@ -432,7 +469,6 @@ void weather_buttons_fill(gboolean check_error){
 		
 		#ifndef RELEASE
 		fprintf(stderr, "\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>");
-		fprintf(stderr, "\nUTC time %s", ctime(&utc_time));
 		fprintf(stderr, "Zone time %s", ctime(&current_time));
 		tmp_time = last_update_time(wcs.current_data);
 		fprintf(stderr, "Last update: %s", ctime(&tmp_time));
@@ -442,7 +478,7 @@ void weather_buttons_fill(gboolean check_error){
 		if( !wcs.current_data_is_invalid && 
 		    (last_update_time(wcs.current_data) > (current_time - app->config->data_valid_interval)) &&
             	    (last_update_time(wcs.current_data) < (current_time + app->config->data_valid_interval)) && i == 0){
-
+		    /* add  time of the termination  valid period */
 		    time_event_add(last_update_time(wcs.current_data) + app->config->data_valid_interval - diff_time, DAYTIMEEVENT);
 		    if(temp_current == INT_MAX)
 			sprintf(buffer,
@@ -491,19 +527,65 @@ void weather_buttons_fill(gboolean check_error){
 				app->config->font_color.green >> 8,
 				app->config->font_color.blue >> 8,
 				item_value(wcs.day_data[i + j], "24h_name"));
-			if(temp_low == INT_MAX)
+                                
+                        memset(app->temperature_string, 0, sizeof(app->temperature_string));
+			if(temp_low == INT_MAX){
+			    sprintf(app->temperature_string + strlen(app->temperature_string), "%s\302\260 - ", _("N/A") );
 			    sprintf(buffer + strlen(buffer), "%s\302\260\n", _("N/A") );
-			else
+			}
+			else{
+			    sprintf(app->temperature_string + strlen(app->temperature_string), "%i\302\260 - ", temp_low );
 			    sprintf(buffer + strlen(buffer), "%i\302\260\n", temp_low );
-			if(temp_hi == INT_MAX)
+			}
+			if(temp_hi == INT_MAX){
+			    sprintf(app->temperature_string + strlen(app->temperature_string), "%s\302\260 ", _("N/A") );
 			    sprintf(buffer + strlen(buffer), "%s\302\260", _("N/A") );
-			else
+			}    
+			else{
+			    sprintf(app->temperature_string + strlen(app->temperature_string), "%i\302\260", temp_hi );
 			    sprintf(buffer + strlen(buffer), "%i\302\260", temp_hi );
+			}    
+			(app->config->temperature_units == CELSIUS) ? ( strcat(app->temperature_string, _("C")) )
+						: ( strcat(app->temperature_string, _("F")) );
+			
 			strcat(buffer, "</span>");
+
+			/* The string of forecast for Combination mode */
+			if((current_time > day_begin_time) && (current_time < night_begin_time)){
+			        memset(app->forecast_string, 0, sizeof(app->forecast_string));
+				strcat(app->forecast_string, item_value(wcs.day_data[i + j], "day_title"));
+				strcat(app->forecast_string, _("\nHumidity: "));
+				if(strcmp(item_value(wcs.day_data[i + j], "day_humidity"), "N/A"))
+				    sprintf(app->forecast_string + strlen(app->forecast_string), "%s%%\n",
+					    item_value(wcs.day_data[i + j], "day_humidity"));
+			        else
+				    sprintf(app->forecast_string + strlen(app->forecast_string), "%s\n",
+					    (char*)hash_table_find((gpointer)"N/A"));
+			        strcat(app->forecast_string, _("Wind: "));
+				sprintf(app->forecast_string + strlen(app->forecast_string), "%s %.2f %s", item_value(wcs.day_data[i + j], "day_wind_title"),
+				convert_wind_units(app->config->wind_units, atof(item_value(wcs.day_data[i + j], "day_wind_speed"))),
+						    (char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units]));
+			}else{
+			        memset(app->forecast_string, 0, sizeof(app->forecast_string));
+				strcat(app->forecast_string, item_value(wcs.day_data[i + j], "night_title"));
+				strcat(app->forecast_string, _("\nHumidity: "));
+				if(strcmp(item_value(wcs.day_data[i + j], "night_humidity"), "N/A"))
+				    sprintf(app->forecast_string + strlen(app->forecast_string), "%s%%\n",
+					    item_value(wcs.day_data[i + j], "night_humidity"));
+				else
+				    sprintf(app->forecast_string + strlen(app->forecast_string), "%s\n",
+					    (char*)hash_table_find((gpointer)"N/A"));
+				strcat(app->forecast_string, _("Wind: "));
+				sprintf(app->forecast_string + strlen(app->forecast_string), "%s %.2f %s", item_value(wcs.day_data[i + j], "night_wind_title"),
+					convert_wind_units(app->config->wind_units, atof(item_value(wcs.day_data[i + j], "night_wind_speed"))),
+					(char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units]));
+			}			
 		    }
 		}
 	    }
-	    else{ /* other days, from two and to app->config->days_to_show */
+	    else{ 
+		(app->config->separate) ? (j = -1) : (j = 0);
+		/* other days, from two and to app->config->days_to_show */
 	    	if(!strcmp(item_value(wcs.day_data[i + j], "24h_hi_temperature"), "N/A"))
 		    temp_hi = INT_MAX;
 		else
@@ -649,6 +731,12 @@ void* hildon_home_applet_lib_initialize(void *state_data, int *state_size,
     }
 /* list of user select stations */
     app->user_stations_list = create_user_stations_list();
+    #ifdef USE_CONIC
+	app->connection = NULL;
+    #endif    
+/* Initialize DBUS */
+    weather_initialize_dbus();
+    
 /* Init gconf. */
     gnome_vfs_init();
     if(new_read_config(app->config)){
@@ -658,6 +746,7 @@ void* hildon_home_applet_lib_initialize(void *state_data, int *state_size,
         exit(1);
     }
 
+
     app->time_update_list = create_time_update_list();
     app->show_update_window = FALSE;
     app->countrys_list = NULL;
@@ -668,8 +757,7 @@ void* hildon_home_applet_lib_initialize(void *state_data, int *state_size,
 /* Start main applet */ 
     app->top_widget = gtk_hbox_new(FALSE, 0);
     weather_buttons_fill(FALSE);
-/* Initialize DBUS */
-    weather_initialize_dbus();
+    
 /*    
     time_event_add(time(NULL) + 5, DBUSINITEVENT);
     add_periodic_event(time(NULL));
@@ -741,6 +829,10 @@ void hildon_home_applet_lib_deinitialize(void *applet_data){
     }
     new_config_save(app->config); /* Not work!!!! Only 770. Why? I am not understand why this place not run when close applet 
 			On n800 this work */
+    #ifdef USE_CONIC
+	if (app->connection)
+	    g_object_unref(app->connection);
+    #endif
     #ifdef HILDON
 	deinitial_gps_connect();
     	g_signal_handler_disconnect(app->parent,app->signal_size_request);
@@ -783,6 +875,7 @@ void hildon_home_applet_lib_deinitialize(void *applet_data){
 	    app->user_stations_list = NULL;
 	}
     }
+    app && (g_free(app), app = NULL);
     /* Deinitialize libosso */
     osso_deinitialize(osso);
 }
@@ -817,14 +910,13 @@ void menu_init(void){
         gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list),
                             &iter,
                             0, &station_name,
-                            1, &station_code,
+    	                    1, &station_code,
                             -1);
 	gtk_menu_shell_append(GTK_MENU_SHELL(app->contextmenu),
 				menu_item = gtk_menu_item_new_with_label(station_name));
 	station_name && (g_free(station_name) , station_name = NULL);
         g_signal_connect(G_OBJECT(menu_item), "activate",
                     	    G_CALLBACK(change_station_select), station_code);
-	station_code && (g_free(station_code) , station_code = NULL);
         valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(app->user_stations_list),
                                                         &iter);
     }
@@ -834,6 +926,67 @@ void menu_init(void){
 }
 /*******************************************************************************/
 /* For Combination layout */
+GtkWidget* create_forecast_weather_simple_widget(char f_size)
+{
+	
+        GtkWidget	*temperature_label = NULL,
+			*main_data_vbox = NULL,
+			*main_data_label = NULL,
+			*main_widget = NULL,
+			*temperature_vbox = NULL;
+
+    	gchar		buffer[1024];
+	calculate_offset_of_day(Max_count_weather_day);
+	/* prepare forecast temperature */
+	temperature_vbox = gtk_vbox_new(FALSE, 0);
+
+        memset(buffer, 0, sizeof(buffer));
+	sprintf(buffer,"<span weight=\"bold\" foreground='#%02x%02x%02x'>",
+				app->config->font_color.red >> 8,
+				app->config->font_color.green >> 8,
+				app->config->font_color.blue >> 8);
+	if (app->temperature_string[0] != 0){
+        	sprintf(buffer + strlen(buffer), _("Forecast: \n"));
+        	strcat(buffer, app->temperature_string);
+	}else{
+        	sprintf(buffer + strlen(buffer), _("The current weather\nis not available"));
+	}
+
+	strcat(buffer,"</span>");
+	temperature_label = gtk_label_new(NULL);
+	gtk_label_set_markup(GTK_LABEL(temperature_label), buffer);
+	gtk_label_set_justify(GTK_LABEL(temperature_label), GTK_JUSTIFY_CENTER);
+
+	if (app->temperature_string[0] != 0)
+        	set_font_size(temperature_label, 1.7*f_size);
+	gtk_box_pack_start(GTK_BOX(temperature_vbox), temperature_label, FALSE, FALSE, 0);
+
+	/* prepare "title" "humidity", "wind", "gust" */
+	main_data_vbox = gtk_vbox_new(FALSE, 0);	
+	memset(buffer, 0, sizeof(buffer));
+        sprintf(buffer,"<span weight=\"bold\" foreground='#%02x%02x%02x'>",
+				app->config->font_color.red >> 8,
+				app->config->font_color.green >> 8,
+				app->config->font_color.blue >> 8);
+        strcat(buffer, app->forecast_string);				
+	strcat(buffer,"</span>");
+	main_data_vbox = gtk_vbox_new(FALSE, 0);	
+	main_data_label = gtk_label_new(NULL);
+	gtk_label_set_markup(GTK_LABEL(main_data_label), buffer);
+        set_font_size(main_data_label, f_size);
+	gtk_box_pack_start(GTK_BOX(main_data_vbox), main_data_label, FALSE, FALSE, 0);
+
+        /* prepare main widget */
+	main_widget = gtk_hbox_new(FALSE, 10);
+	gtk_box_pack_start(GTK_BOX(main_widget), temperature_vbox, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(main_widget), main_data_vbox, FALSE, FALSE, 0);
+
+
+	return main_widget;
+
+}
+/*******************************************************************************/
+/* For Combination layout */
 GtkWidget* create_current_weather_simple_widget(GSList *current, char f_size){
     GtkWidget	*main_widget = NULL,
 		*temperature_vbox,
@@ -844,10 +997,7 @@ GtkWidget* create_current_weather_simple_widget(GSList *current, char f_size){
     gchar	buffer[1024],
 		*units;
     const gchar	*wind_units_str[] = {	"m/s",
-/*					"km/s",
-					"mi/s",
-					"m/h",
-*/					"km/h",
+					"km/h",
 					"mi/h"
 				    };
     float	tmp_distance = 0;
@@ -857,6 +1007,7 @@ GtkWidget* create_current_weather_simple_widget(GSList *current, char f_size){
 #endif
     if(!current)
 	return NULL;
+
 /* prepare current temperature */
     temperature_vbox = gtk_vbox_new(FALSE, 0);
     memset(buffer, 0, sizeof(buffer));
@@ -874,6 +1025,7 @@ GtkWidget* create_current_weather_simple_widget(GSList *current, char f_size){
     strcat(buffer,"</span>");
     temperature_label = gtk_label_new(NULL);
     gtk_label_set_markup(GTK_LABEL(temperature_label), buffer);
+    gtk_label_set_justify(GTK_LABEL(temperature_label), GTK_JUSTIFY_CENTER);
     set_font_size(temperature_label, 2*f_size);
 
     gtk_box_pack_start(GTK_BOX(temperature_vbox), temperature_label, FALSE, FALSE, 0);
@@ -978,6 +1130,9 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency,
 		*station_name_btn = NULL,
 		*station_name = NULL,
 		*station_box = NULL;
+    time_t	current_time,
+                diff_time,
+                utc_time;
     int		n, elements, x, y;
     GtkTreeIter	iter;
     gboolean	valid = FALSE,
@@ -1173,8 +1328,19 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency,
     /* attach to main panel header and days panels */
     if(layout == COMBINATION){
         combination_vbox = gtk_vbox_new(FALSE, 0);
-	if(!wcs.current_data_is_invalid)
-	    current_weather_widget = create_current_weather_simple_widget(wcs.current_data, f_size);
+	/* get current time */  
+        current_time = time(NULL);
+        utc_time = mktime(gmtime(&current_time));
+        diff_time = utc_time - current_time + 60 * 60 * atol(item_value(wcs.day_data[0], "station_time_zone"));
+        current_time += diff_time;
+	
+        if(!wcs.current_data_is_invalid){
+	    if( (last_update_time(wcs.current_data) > (current_time - app->config->data_valid_interval)) &&
+    		(last_update_time(wcs.current_data) < (current_time + app->config->data_valid_interval))){
+		current_weather_widget = create_current_weather_simple_widget(wcs.current_data, f_size);
+	    }else
+	    	current_weather_widget = create_forecast_weather_simple_widget(f_size);
+	}
 	gtk_box_pack_start(GTK_BOX(combination_vbox), header_panel, FALSE, FALSE, 0);
 	if(current_weather_widget)
 	    gtk_box_pack_start(GTK_BOX(combination_vbox), current_weather_widget, FALSE, FALSE, 0);
